###########################
Contributing to ligo.skymap
###########################

ligo.skymap welcomes code contributions and issue reports. The ligo.skymap
project lives on `git.ligo.org <https://git.ligo.org>`_, the LIGO Scientific
Collaboration's and Virgo Collaboration's GitLab instance. Contributors that
are members of LIGO, Virgo, or KAGRA and have a @ligo.org email address should
submit issues and merge requests through the GitLab project page at
https://git.ligo.org/lscsoft/ligo.skymap.

Contributors who are not members of LIGO, Virgo, or KAGRA can submit issues or
pull requests through the project's GitHub mirror at
https://github.com/lpsinger/ligo.skymap.
